==> fet_5.5.5.orig.tar.gz: fet-5.5.5/src/interface/modifyconstraintteachersminhoursdailyform.h <==
/***************************************************************************
                          modifyconstraintteachersminhoursdailyform.h  -  description
                             -------------------
    begin                : Sept. 21, 2007
    copyright            : (C) 2007 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef MODIFYCONSTRAINTTEACHERSMINHOURSDAILYFORM_H
#define MODIFYCONSTRAINTTEACHERSMINHOURSDAILYFORM_H

#include "modifyconstraintteachersminhoursdailyform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

#include <q3combobox.h>
#include <qmessagebox.h>
#include <q3groupbox.h>
#include <qspinbox.h>
#include <qcheckbox.h>
#include <qpushbutton.h>
#include <qlineedit.h>
#include <q3textedit.h>

class ModifyConstraintTeachersMinHoursDailyForm : public ModifyConstraintTeachersMinHoursDailyForm_template  {
public:
	ConstraintTeachersMinHoursDaily* _ctr;

	ModifyConstraintTeachersMinHoursDailyForm(ConstraintTeachersMinHoursDaily* ctr);
	~ModifyConstraintTeachersMinHoursDailyForm();

	void updateMinHoursSpinBox();

	void constraintChanged();
	void ok();
	void cancel();
};

#endif

==> fet_5.11.0.orig.tar.gz: fet-5.11.0/src/interface/modifyconstraintteachersminhoursdailyform.h <==
/***************************************************************************
                          modifyconstraintteachersminhoursdailyform.h  -  description
                             -------------------
    begin                : Sept. 21, 2007
    copyright            : (C) 2007 by Lalescu Liviu
    email                : Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef MODIFYCONSTRAINTTEACHERSMINHOURSDAILYFORM_H
#define MODIFYCONSTRAINTTEACHERSMINHOURSDAILYFORM_H

#include "ui_modifyconstraintteachersminhoursdailyform_template.h"
#include "timetable_defs.h"
#include "timetable.h"
#include "fet.h"

#include <q3combobox.h>
#include <qmessagebox.h>
#include <q3groupbox.h>
#include <qspinbox.h>
#include <qcheckbox.h>
#include <qpushbutton.h>
#include <qlineedit.h>
#include <q3textedit.h>

class ModifyConstraintTeachersMinHoursDailyForm : public QDialog, Ui::ModifyConstraintTeachersMinHoursDailyForm_template  {
	Q_OBJECT
public:
	ConstraintTeachersMinHoursDaily* _ctr;

	ModifyConstraintTeachersMinHoursDailyForm(ConstraintTeachersMinHoursDaily* ctr);
	~ModifyConstraintTeachersMinHoursDailyForm();

	void updateMinHoursSpinBox();

public slots:
	void constraintChanged();
	void ok();
	void cancel();
};

#endif
